@@ -16,7 +16,7 @@ pub type SharedState = Arc<Mutex<State>>;
 
 /// Represents the current status of a group.
 /// Each group acts as a queue and can be managed individually.
-#[derive(Clone, Debug, Deserialize, Serialize)]
+#[derive(PartialEq, Clone, Debug, Deserialize, Serialize)]
 pub enum GroupStatus {
     Running,
     Paused,
@@ -45,7 +45,7 @@ pub enum GroupStatus {
 /// The daemon uses the state as a piece of shared memory between it's threads.
 /// It's wrapped in a MutexGuard, which allows us to guarantee sequential access to any crucial
 /// information, such as status changes and incoming commands by the client.
-#[derive(Clone, Debug, Deserialize, Serialize)]
+#[derive(PartialEq, Clone, Debug, Deserialize, Serialize)]
 pub struct State {
     /// The current settings used by the daemon.
     pub settings: Settings,
@@ -363,7 +363,10 @@ impl State {
     }
 
     /// Restore the last state from a previous session. \
-    /// The state is stored as json in the log directory.
+    /// The state is stored as json in the `pueue_directory`.
+    ///
+    /// If the state cannot be deserialized, an empty default state will be used instead. \
+    /// All groups with queued tasks will be automatically paused to prevent unwanted execution.
     pub fn restore(&mut self) -> Result<(), Error> {
         let path = Path::new(&self.settings.shared.pueue_directory()).join("state.json");
 
